@@ -1,7 +1,11 @@
 package Perl::Examples::Accessors::Mouse;
 
-our $DATE = '2021-08-03'; # DATE
-our $VERSION = '0.132'; # VERSION
+use strict;
+
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2024-05-06'; # DATE
+our $DIST = 'Perl-Examples-Accessors'; # DIST
+our $VERSION = '0.133'; # VERSION
 
 use Mouse;
 
@@ -23,7 +27,7 @@ Perl::Examples::Accessors::Mouse
 
 =head1 VERSION
 
-This document describes version 0.132 of Perl::Examples::Accessors::Mouse (from Perl distribution Perl-Examples-Accessors), released on 2021-08-03.
+This document describes version 0.133 of Perl::Examples::Accessors::Mouse (from Perl distribution Perl-Examples-Accessors), released on 2024-05-06.
 
 =head1 DESCRIPTION
 
@@ -47,6 +51,35 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perl-Examp
 
 Source repository is at L<https://github.com/perlancar/perl-Perl-Examples-Accessors>.
 
+=head1 AUTHOR
+
+perlancar <perlancar@cpan.org>
+
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2024, 2017, 2016 by perlancar <perlancar@cpan.org>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Perl-Examples-Accessors>
@@ -55,15 +88,4 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
-=head1 AUTHOR
-
-perlancar <perlancar@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2021, 2017, 2016 by perlancar@cpan.org.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
